Summary:        Perl compatible regular expression library
Name:           pcre2
Version:        10.42
Release:        6%{?dist}
License:        BSD
URL:            https://www.pcre.org/
Source0:        https://github.com/PCRE2Project/%{name}/releases/download/%{name}-%{version}/%{name}-%{version}.tar.bz2
Patch3000:      pcre2-10.10-Fix-multilib.patch

BuildRequires:  autoconf automake gcc make libtool
BuildRequires:  readline-devel
Requires:       %{name}-doc = %{version}-%{release}
Provides:       bundled(sljit)

%description
The PCRE library is a set of functions that implement regular expression pattern matching
using the same syntax and semantics as Perl 5. PCRE has its own native API, as well as
a set of wrapper functions that correspond to the POSIX regular expression API.
It comes in three forms, for processing 8-bit, 16-bit, or 32-bit code units,
in either literal or UTF encoding.

PCRE2 was first released in 2015 to replace the API in the original PCRE library,
which is now obsolete and no longer maintained. 

PCRE2 html documents is https://pcre2project.github.io/pcre2/doc/html/index.html.


%package doc
Summary:        Documentation for PCRE2
BuildArch:      noarch

%description doc
Document for syntax of the regular expressions implemented by the PCRE2 library.


%package utf16
Summary:        UTF-16 form of PCRE2
Requires:       %{name}-doc = %{version}-%{release}
Provides:       bundled(sljit)

%description utf16
PCRE2 library working on UTF-16 strings.


%package utf32
Summary:        UTF-32 form of PCRE2
Requires:       %{name}-doc = %{version}-%{release}
Provides:       bundled(sljit)

%description utf32
PCRE2 library working on UTF-32 strings.


%package devel
Summary:        Development files for PCRE2
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-utf16 = %{version}-%{release}
Requires:       %{name}-utf32 = %{version}-%{release}

%description devel
Headers, libraries for pcre2.


%package static
Summary:        Static library for PCRE2
Requires:       %{name}-devel = %{version}-%{release}
Provides:       bundled(sljit)

%description static
Static library for pcre2.


%package tools
Summary:        Utilities for pcre2
# pcre2test (linked to GNU readline)
License:        BSD and GPLv3+
Requires:       %{name} = %{version}-%{release}

%description tools
Utilities demonstrating PCRE2 capabilities like pcre2grep or pcre2test.


%prep
%autosetup -n %{name}-%{version} -p1


%build
autoreconf -vif
%configure \
%ifnarch loongarch64
	   --enable-jit \
%endif
           --disable-jit-sealloc \
           --enable-pcre2grep-jit \
           --enable-pcre2-8 \
           --enable-pcre2-16 \
           --enable-pcre2-32 \
           --enable-pcre2grep-callout \
           --enable-pcre2grep-callout-fork \
           --disable-pcre2grep-libbz2 \
           --disable-pcre2grep-libz \
           --disable-pcre2test-libedit \
           --enable-pcre2test-libreadline \
           --disable-bsr-anycrlf \
           --enable-newline-is-lf \
           --disable-ebcdic \
           --disable-fuzz-support \
           --disable-never-backslash-C \
           --enable-percent-zt \
           --disable-rebuild-chartables \
           --disable-silent-rules \
           --enable-shared \
           --enable-static \
           --enable-unicode \
           --disable-coverage \
           --disable-valgrind
%make_build


%install
%make_install
rm -f %{buildroot}%{_libdir}/*.la
rm -rf %{buildroot}%{_docdir}/pcre2


%check
%make_build check


%files
%{_libdir}/libpcre2-8.so.0*
%{_libdir}/libpcre2-posix.so.3*

%files doc
%license COPYING LICENCE
%doc AUTHORS ChangeLog NEWS
%{_mandir}/man3/pcre2.*
%{_mandir}/man3/pcre2compat.*
%{_mandir}/man3/pcre2limits.*
%{_mandir}/man3/pcre2matching.*
%{_mandir}/man3/pcre2partial.*
%{_mandir}/man3/pcre2pattern.*
%{_mandir}/man3/pcre2perform.*
%{_mandir}/man3/pcre2syntax.*
%{_mandir}/man3/pcre2unicode.*

%files utf16
%{_libdir}/libpcre2-16.so.0*

%files utf32
%{_libdir}/libpcre2-32.so.0*

%files devel
%doc README HACKING ./src/pcre2demo.c
%doc doc/*.txt doc/html
%{_bindir}/pcre2-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*.h
%{_mandir}/man1/pcre2-config.*
%{_mandir}/man3/pcre2_*
%{_mandir}/man3/pcre2api.*
%{_mandir}/man3/pcre2build.*
%{_mandir}/man3/pcre2callout.*
%{_mandir}/man3/pcre2convert.*
%{_mandir}/man3/pcre2demo.*
%{_mandir}/man3/pcre2jit.*
%{_mandir}/man3/pcre2posix.*
%{_mandir}/man3/pcre2sample.*
%{_mandir}/man3/pcre2serialize*

%files static
%license COPYING LICENCE
%{_libdir}/*.a

%files tools
%{_bindir}/pcre2grep
%{_bindir}/pcre2test
%{_mandir}/man1/pcre2grep.*
%{_mandir}/man1/pcre2test.*

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 10.42-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 10.42-5
- Rebuilt for loongarch release

* Tue Apr 2 2024 luffyluo <luffyluo@tencent.com> - 10.42-4
- Fix error changelog format

* Fri Mar 15 2024 Wenlong Zhang <zhangwenlong@loongson.cn> - 10.42-3
- disable jit for loongarch64

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 10.42-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 02 2023 kianli <kianli@tencent.com> - 10.42-1
- Upgrade to 10.42

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 10.40-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 10.40-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Jun 27 2022 rockerzhu <rockerzhu@tencent.com> - 10.40-1
- Initial build
